@@ -19,12 +19,9 @@ GtkWidget *txt_icon;
 GtkWidget *txt_exec;
 GtkWidget *ctree;
 GtkWidget *btn_browse;
-GtkWidget *btn_browse2;
 GtkWidget *lbl_params;
 GtkWidget *statusbar;
 
-static void on_resort_columns(GtkWidget *widget, gint column, gpointer user_data);
-
 void
 load_new_menu_from_disk (char *file_to_load, GtkCTreeNode * my_parent)
 {
@@ -216,7 +213,6 @@ selection_made (GtkCTree * my_ctree, GList * node, gint column,
       gtk_widget_set_sensitive (GTK_WIDGET (txt_icon), TRUE);
       gtk_widget_set_sensitive (GTK_WIDGET (txt_description), TRUE);
       gtk_widget_set_sensitive (GTK_WIDGET (btn_browse), TRUE);
-      gtk_widget_set_sensitive (GTK_WIDGET (btn_browse2), TRUE);
       first = 0;
     }
   last_node = GTK_CTREE_NODE ((GTK_CLIST (ctree)->selection)->data);
@@ -326,9 +322,6 @@ create_main_window (void)
   gtk_clist_set_reorderable (GTK_CLIST (ctree), TRUE);
   gtk_signal_connect (GTK_OBJECT (ctree), "tree-select-row",
 		      GTK_SIGNAL_FUNC (selection_made), NULL);
-  gtk_signal_connect(GTK_OBJECT(ctree), "click_column",
-            GTK_SIGNAL_FUNC(on_resort_columns), NULL);
-
   gtk_widget_show (ctree);
 
   vbox = gtk_vbox_new (FALSE, 3);
@@ -406,20 +399,12 @@ create_main_window (void)
 
   txt_exec = entry = gtk_entry_new_with_max_length (200);
   gtk_widget_show (entry);
-  gtk_table_attach (GTK_TABLE (table), entry, 1, 2, 2, 3,
+  gtk_table_attach (GTK_TABLE (table), entry, 1, 3, 2, 3,
 		    GTK_EXPAND | GTK_FILL, (GtkAttachOptions) (0), 0, 0);
   gtk_signal_connect_after (GTK_OBJECT (txt_exec), "key_press_event",
 			    GTK_SIGNAL_FUNC (entries_to_ctree), NULL);
   gtk_widget_set_sensitive (GTK_WIDGET (txt_exec), FALSE);
 
-  btn_browse2 = gtk_button_new_with_label ("Browse");
-  gtk_widget_show (btn_browse2);
-  gtk_table_attach (GTK_TABLE (table), btn_browse2, 2, 3, 2, 3,
-		    (GtkAttachOptions) 0, (GtkAttachOptions) (0), 0, 0);
-  gtk_signal_connect (GTK_OBJECT (btn_browse2), "clicked",
-		      GTK_SIGNAL_FUNC (cb_exec_browse), NULL);
-  gtk_widget_set_sensitive (GTK_WIDGET (btn_browse2), FALSE);
-
   hbox = gtk_hbox_new (FALSE, 3);
   gtk_widget_show (hbox);
   gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 2);
@@ -834,8 +819,6 @@ cb_icon_browse_ok (GtkWidget * widget, gpointer user_data)
 
   gtk_entry_set_text (GTK_ENTRY (txt_icon), file);
 
-  entries_to_ctree(GTK_WIDGET (txt_icon), NULL);
-
   gtk_widget_destroy (GTK_WIDGET (user_data));
 
   return;
@@ -843,59 +826,6 @@ cb_icon_browse_ok (GtkWidget * widget, gpointer user_data)
   user_data = NULL;
 }
 
-void
-cb_exec_browse (GtkWidget * widget, gpointer user_data)
-{
-  GtkWidget *fs;
-  gchar *file;
-
-  fs = gtk_file_selection_new ("Select executable file");
-
-  file = gtk_entry_get_text (GTK_ENTRY (txt_exec));
-
-  gtk_file_selection_set_filename (GTK_FILE_SELECTION (fs), file);
-
-  gtk_signal_connect (GTK_OBJECT (GTK_FILE_SELECTION (fs)->cancel_button),
-		      "clicked", GTK_SIGNAL_FUNC (cb_exec_browse_cancel),
-		      (gpointer) fs);
-
-  gtk_signal_connect (GTK_OBJECT (GTK_FILE_SELECTION (fs)->ok_button),
-		      "clicked", GTK_SIGNAL_FUNC (cb_exec_browse_ok),
-		      (gpointer) fs);
-
-  gtk_widget_show (fs);
-  return;
-  widget = NULL;
-  user_data = NULL;
-
-}
-
-void
-cb_exec_browse_ok (GtkWidget * widget, gpointer user_data)
-{
-  gchar *file;
-  file = gtk_file_selection_get_filename (GTK_FILE_SELECTION (user_data));
-
-  gtk_entry_set_text (GTK_ENTRY (txt_exec), file);
-  entries_to_ctree (GTK_WIDGET (txt_exec), NULL);
-
-  gtk_widget_destroy (GTK_WIDGET (user_data));
-
-  return;
-  widget = NULL;
-  user_data = NULL;
-
-}
-
-void
-cb_exec_browse_cancel (GtkWidget * widget, gpointer user_data)
-{
-  gtk_widget_destroy (GTK_WIDGET (user_data));
-  return;
-  widget = NULL;
-  user_data = NULL;
-}
-
 void
 status_message (gchar * message, gint delay)
 {
@@ -910,36 +840,3 @@ status_clear (gpointer user_data)
   return FALSE;
   user_data = NULL;
 }
-
-void
-on_resort_columns(GtkWidget *widget, gint column, gpointer user_data)
-{
-    static int order=0;
-    static int last_col=0;
-    GtkCList *clist;
-
-    clist = GTK_CLIST(ctree);
-
-    if(user_data) {
-        widget = NULL;
-    } 
-    gtk_clist_set_sort_column(GTK_CLIST(clist),column);
-    if(last_col == column) {
-        if(order) {
-            order=0;
-            gtk_clist_set_sort_type(GTK_CLIST(clist),GTK_SORT_DESCENDING);
-        } else {
-            order=1;
-            gtk_clist_set_sort_type(GTK_CLIST(clist),GTK_SORT_ASCENDING);
-        }
-    } else {
-        order=1;
-        gtk_clist_set_sort_type(GTK_CLIST(clist),GTK_SORT_ASCENDING);
-        last_col = column;
-    }
-
-    gtk_clist_sort(GTK_CLIST(clist));
-
-    return;
-
-}
